@@ -70,9 +70,7 @@ sub _ipdiscover_prolog_resp{
   my $resp = shift;
   
   my ($ua, $os, $v);
-
-  return unless (ref $current_context->{'PARAMS'}{'IPDISCOVER'} eq ref {}); # Not a HASH reference
-
+ 
   my $lanToDiscover = $current_context->{'PARAMS'}{'IPDISCOVER'}->{'TVALUE'};
   my $behaviour     = $current_context->{'PARAMS'}{'IPDISCOVER'}->{'IVALUE'};
   my $groupsParams  = $current_context->{'PARAMS_G'};
@@ -149,8 +147,6 @@ sub _ipdiscover_main{
   my $current_context = shift;
 
   return if $current_context->{'LOCAL_FL'};
-
-  return unless (ref $current_context->{'PARAMS'}{'IPDISCOVER'} eq ref {}); # Not a HASH reference
   
   my $DeviceID = $current_context->{'DATABASE_ID'};
   my $dbh = $current_context->{'DBI_HANDLE'};
@@ -239,7 +235,6 @@ sub _ipdiscover_read_result{
   my $update_req;
   my $insert_req;
   my $request;
-  my $DeviceID = $Apache::Ocsinventory::CURRENT_CONTEXT{'DATABASE_ID'};
 
   if(exists($result->{CONTENT}->{IPDISCOVER})){
     my $base = $result->{CONTENT}->{NETWORKS};
@@ -251,63 +246,22 @@ sub _ipdiscover_read_result{
         last;
       }    
     }
-
+    
+    # We insert the results (MAC/IP)
+    $update_req = $dbh->prepare('UPDATE netmap SET IP=?,MASK=?,NETID=?,DATE=NULL, NAME=? WHERE MAC=?');
+    $insert_req = $dbh->prepare('INSERT INTO netmap(IP, MAC, MASK, NETID, NAME) VALUES(?,?,?,?,?)');
+    
     $base = $result->{CONTENT}->{IPDISCOVER}->{H};
-
-    if( $ENV{'OCS_OPT_IPDISCOVER_LINK_TAG_NETWORK'} ) {
-      my $request_tag = $dbh->prepare('SELECT TAG FROM accountinfo WHERE HARDWARE_ID=?');
-      my $tag = undef;
-
-      unless($request_tag->execute($DeviceID)){
-          &_log(519,'ipdiscover','computer tag error') if $ENV{'OCS_OPT_LOGLEVEL'};
-          return(1);
+    for(@$base){
+      unless($_->{I}=~/^(\d{1,3}(?:\.\d{1,3}){3})$/ and $_->{M}=~/.{2}(?::.{2}){5}/){
+        &_log(1003,'ipdiscover','bad_result') if $ENV{'OCS_OPT_LOGLEVEL'};
+        next;
       }
-
-      my $row = $request_tag->fetchrow_hashref;
-
-      if (defined $row->{'TAG'}) {
-        $tag = $row->{'TAG'};
-      }
-
-      # We insert the results (MAC/IP)
-      for(@$base){
-        unless($_->{I}=~/^(\d{1,3}(?:\.\d{1,3}){3})$/ and $_->{M}=~/.{2}(?::.{2}){5}/){
-          &_log(1003,'ipdiscover','bad_result') if $ENV{'OCS_OPT_LOGLEVEL'};
-          next;
-        }
-        my $request_verif = $dbh->prepare('SELECT TAG FROM netmap WHERE MAC=?');
-        $request_verif->execute($_->{M});
-        my $row_verif = $request_verif->fetchrow_hashref;
-
-        if (defined $row_verif->{'TAG'}) {
-          $update_req = $dbh->prepare('UPDATE netmap SET IP=?,MASK=?,NETID=?,DATE=NOW(), NAME=? WHERE MAC=? AND TAG=?');
-          $update_req->execute($_->{I}, $mask, $subnet, $_->{N}, $_->{M}, $tag);
-        } else {
-          $update_req = $dbh->prepare('UPDATE netmap SET IP=?,MASK=?,NETID=?,DATE=NOW(), NAME=?, TAG=? WHERE MAC=?');
-          $update_req->execute($_->{I}, $mask, $subnet, $_->{N}, $tag, $_->{M});
-        }
-        unless($update_req->rows){
-          $insert_req = $dbh->prepare('INSERT INTO netmap(IP, MAC, MASK, NETID, NAME, TAG) VALUES(?,?,?,?,?,?)');
-          $insert_req->execute($_->{I}, $_->{M}, $mask, $subnet, $_->{N}, $tag);
-        }
-      }
-    } else {
-      # We insert the results (MAC/IP)
-      $update_req = $dbh->prepare('UPDATE netmap SET IP=?,MASK=?,NETID=?,DATE=NOW(), NAME=? WHERE MAC=?');
-      $insert_req = $dbh->prepare('INSERT INTO netmap(IP, MAC, MASK, NETID, NAME) VALUES(?,?,?,?,?)');
-
-      for(@$base){
-        unless($_->{I}=~/^(\d{1,3}(?:\.\d{1,3}){3})$/ and $_->{M}=~/.{2}(?::.{2}){5}/){
-          &_log(1003,'ipdiscover','bad_result') if $ENV{'OCS_OPT_LOGLEVEL'};
-          next;
-        }
-        $update_req->execute($_->{I}, $mask, $subnet, $_->{N}, $_->{M});
-        unless($update_req->rows){
-          $insert_req->execute($_->{I}, $_->{M}, $mask, $subnet, $_->{N});
-        }
+      $update_req->execute($_->{I}, $mask, $subnet, $_->{N}, $_->{M});
+      unless($update_req->rows){
+        $insert_req->execute($_->{I}, $_->{M}, $mask, $subnet, $_->{N});
       }
     }
-
     $dbh->commit;
   }else{
     return 1;
@@ -321,13 +275,6 @@ sub _ipdiscover_read_result{
     return 1;
   }
   
-  # check ignored subnet
-  $request=$dbh->prepare('SELECT SUBNET FROM blacklist_subnet WHERE SUBNET=?');
-  $request->execute($subnet);
-  if($request->rows > 0){
-    return 1;
-  }
-
   return 0;
 }
 
@@ -347,13 +294,6 @@ sub _ipdiscover_find_iface{
         if($_->{IPMASK}=~/^(?:255\.){2}|^0x(?:ff){2}/){
           if($_->{IPSUBNET}=~/^(\d{1,3}(?:\.\d{1,3}){3})$/){
   
-    # check ignored subnet
-    $request = $dbh->prepare('SELECT SUBNET FROM blacklist_subnet WHERE SUBNET=?');
-    $request->execute($_->{IPSUBNET});
-    if($request->rows > 0){
-      next;
-    }
-
     # Looking for a need of ipdiscover
     $request = $dbh->prepare('SELECT HARDWARE_ID FROM devices WHERE TVALUE=? AND NAME="IPDISCOVER"');
     $request->execute($_->{IPSUBNET});
@@ -419,7 +359,7 @@ sub _ipdiscover_evaluate{
             return 1;
           }
           $dbh->commit;
-           &_log(1001,'ipdiscover',($over?'over':'better')."($_->{IPSUBNET})"."(OLD=($worth[0],$worth[1]),NEW=($DeviceID,$quality))(THRESHOLD=$ENV{'OCS_OPT_IPDISCOVER_BETTER_THRESHOLD'})") if $ENV{'OCS_OPT_LOGLEVEL'};
+          &_log(1001,'ipdiscover',($over?'over':'better')."($_->{IPSUBNET})") if $ENV{'OCS_OPT_LOGLEVEL'};
           return 0;
         }
       }
