@@ -22,13 +22,11 @@ my $help;
 my $directory;
 my $file;
 my $url;
-my $sslmode;
-my $cafile;
 my $useragent;
 my $remove;
 my $verbose;
 my $stdin;
-my $timeout;
+
 
 sub loadfile {
     $file = shift;
@@ -78,15 +76,7 @@ sub loadstdin {
 sub sendContent {
     my $content = shift;
 
-    my $ua = LWP::UserAgent->new(
-        protocols_allowed => ['http', 'https'],
-        timeout           => $timeout,
-        ssl_opts => { 
-            verify_hostname => $sslmode,
-            SSL_ca_file => $cafile
-        },
-    );
-
+    my $ua = LWP::UserAgent->new;
     $ua->agent($useragent);
     my $request = HTTP::Request->new( POST => $url );
     $request->header(
@@ -112,23 +102,21 @@ sub usage {
 
     print <<EOF;
 
-    DESCRIPTION:
-        A command line tools to import .ocs files.
+	DESCRIPTION:
+    	A command line tools to import .ocs files.
 
-    USAGE:
-    -h --help	: this menu
-    -d --directory	: load every .ocs files from a directory
-    -f --file\	: load a speficic file
-    -u --url	: ocsinventory backend URL, default is http://ocsinventory-ng/ocsinventory
-    --sslmode   : 1 or 0, enable SSL inventory injection
-    --cafile    : path to certificate
-    --useragent	: HTTP user agent, default is OCS-NG_LOCAL_PL_v".VERSION."
-    -r --remove	: remove successfully injected files
-    -v --verbose	: verbose mode
-    -t --timeout	: injector timeout value 
-    --stdin		: read data from STDIN
+	USAGE:
+	-h --help	: this menu
+	-d --directory	: load every .ocs files from a directory
+	-f --file\	: load a speficic file
+	-u --url	: ocsinventory backend URL, default is http://ocsinventory-ng/ocsinventory
+	--useragent	: HTTP user agent, default is OCS-NG_LOCAL_PL_v".VERSION."
+	-r --remove	: remove successfully injected files
+	-m --msg	: show message returned my ocsinventory
+	-v --verbose	: verbose mode
+	--stdin		: read data from STDIN
 
-    You can specify a --file or a --directory or STDIN. Current directory is the default
+You can specify a --file or a --directory or STDIN. Current directory is the default
 
 EOF
     exit 1;
@@ -139,12 +127,9 @@ GetOptions(
     'd|directory=s'	=> \$directory,
     'f|file=s'		=> \$file,
     'u|url=s'		=> \$url,
-    'sslmode=s'     => \$sslmode,
-    'cafile=s'		=> \$cafile,
     'useragent=s'	=> \$useragent,
     'r|remove'		=> \$remove,
     'v|verbose'		=> \$verbose,
-    't|timeout'		=> \$timeout,
     'stdin'		=> \$stdin,
 );
 
@@ -152,9 +137,6 @@ GetOptions(
 $url		= 'http://localhost/ocsinventory' unless $url;
 $useragent	= 'OCS-NG_INJECTOR_PL_v'.VERSION unless $useragent;
 $directory	= '.' unless $directory;
-$sslmode	= 0 unless $sslmode;
-$cafile	    = "cacert.pem" unless $cafile;
-$timeout	= 10 unless $timeout;
 ###
 
 $|=1;
